# Gornilo-Checker

This is a checker wrapper lib.

#### Features:

- no exit-code/chk-sys interface requirements
- object model
- built-in error handling
- asyncio support
- stdout redirect (print defaults for stderr)
- testing output


#### How to: 

See `checker.py` :) 
Use TEST for debugging 
 
